@@ -717,7 +717,8 @@ _msg_handler(DBusConnection *conn, DBusMessage *msg, void *data)
     return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 
-inline int __attribute__ ((visibility("hidden")))
+/*Don't inline the functions, it breaks build on gcc 4.3.x*/
+int __attribute__ ((visibility("hidden")))
 muali_convert_msgtype(int t)
 {
     switch (t) {
